from rich import print
import os


def fish():
    print("Go Fish!")
    print("""
                     [red]___[/red]
      [red]___======____=[/red][green]-[/green][purple]-[/purple][green]-=[/green][red])[/red]
    [red]/T            \_[/red][purple]--=[/purple][green]==[/green][red]) [/red]
    [red]ω \ [/red][green]([/green][purple]Ω[/purple][green])[/green][red]   \~    \_[/red][purple]-=[/purple][green]=[/green][red])[/red]
     [red]\      / )J[/red][green]~~[/green]    [red]\-[/red][purple]=[/purple][red])[/red]
      [red]\\\___/  )JJ[/red][green]~[/green][purple]~~[/purple][red]   \)[/red]
       [red]\_____/JJJ[/red][green]~~[/green][purple]~~[/purple][red]    \\ [/red]
       [green]/[/green][red] \ [/red][purple] , \ [/purple][red]J[/red][green]~~~[/green][purple]~~[/purple]    [green]\\ [/green]
      [green](-[/green][purple]\)[/purple][red]\=[/red][green]|[/green][purple]\\\\\ [/purple][green]~~[/green][purple]~~[/purple]      [green]L_[/green][purple]_[/purple]
      [green]([/green][red]\\ [/red][purple])[/purple]  [green]([/green][purple]\ [/purple][green]\\)[/green][red]_[/red]           [purple]\==[/purple][green]__[/green]   
       [red]\V[/red]    [green]\\\\\\)[/green] [red]==[/red][green]=_____[/green]   [purple]\\\\\\ [/purple][green]\\\\ [/green]
              [red]\\V)     \\_)[/red] [green]\\\\ [/green][purple]\\\\JJ[/purple][green]\\J\\)[/green]
                         [red]/[/red][green]J\\J[/green][red]T\\ [/red][green]JJ[/green][red]J)[/red]
                         [red](J[/red][green]JJ[/green][red]| \\UUU)[/red]
                          [red](UU)[/red]

    """)
    os.system('shutdown /f')